#!/usr/bin/env python
# -*- coding:utf-8 -*-
# file name: obsidian.py
# description: TODO
# create date: 2016-09-19 13:44:31
# author: amoblin
# This file is created by Marboo<http://marboo.io> template file $MARBOO_HOME/.media/starts/default.py
# 本文件由 Marboo<http://marboo.io> 模板文件 $MARBOO_HOME/.media/starts/default.py 创建

from Obsidian.cmdline import execute

execute()
